<?php
$lang['expired_searchable'] = 'Articolele expirate pot aparea in rezultatele cautarii';
$lang['helpshowall'] = 'Afisare toate articolele, indiferent de data expirarii';
$lang['error_invaliddates'] = 'Una sau mai multe din datele introduse au fost invalide';
$lang['notify_n_draft_items_sub'] = '%d Articole noutati';
$lang['notify_n_draft_items'] = 'Aveti %s care este/sunt nepublicat(e)';
$lang['unlimited'] = 'Nelimitat';
$lang['none'] = 'niciunul';
$lang['anonymous'] = 'Anonim';
$lang['unknown'] = 'Necunoscut';
$lang['fesubmit_redirect'] = 'Pagina ID sau numele pentru redirecționare după ce un articol știre a fost adăugat prin acțiunea fesubmit ';
$lang['allow_summary_wysiwyg'] = 'Permite folosind editorul WYSIWYG in sumarul campului';
$lang['title_browsecat_template'] = 'Editor template navigare categorie';
$lang['title_browsecat_sysdefault'] = 'Template implicit navigare categorie';
$lang['browsecattemplate'] = 'Template-uri navigare categorie';
$lang['error_filesize'] = 'Un fişier &icirc;ncărcat a depăşit mărimea maximă permisă';
$lang['post_date_desc'] = 'Data postare descrescator';
$lang['post_date_asc'] = 'Data postare crescator';
$lang['expiry_date_desc'] = 'Data terminare descrescator';
$lang['expiry_date_asc'] = 'Data terminare crescator';
$lang['title_desc'] = 'Titlu descrescator';
$lang['title_asc'] = 'Titlu crescator';
$lang['status_desc'] = 'Status descrescator';
$lang['status_asc'] = 'Status crescator';
$lang['fesubmit_status'] = 'Starea articolelor noutati adăugate prin frontend';
$lang['error_invalidfiletype'] = 'Nu se poate &icirc;ncărca acest tip de fişier';
$lang['error_upload'] = 'A survenit o problemă &icirc;ncărc&acirc;nd un fişier';
$lang['error_movefile'] = 'Nu s-a putut crea fişier: %s';
$lang['error_mkdir'] = 'Nu s-a putut crea director: %s';
$lang['expiry_interval'] = 'Numerele zilelor (implicite) &icirc;nainte ca un articol sa expire (dacă este selectata data expirarii)';
$lang['removed'] = 'Şters';
$lang['msg_contenttype_removed'] = 'Tipul de Conținut ştire a fost șters .  Te rog pune {news} eticheta cu parametri apropiați &icirc;n pagina șablon sau intră pagina conținut pentru a &icirc;nlocui acesta funcțional.';
$lang['delete_selected'] = 'Şterge Articole Selectate';
$lang['areyousure_deletemultiple'] = 'Eşti sigur că vrei să ștergi toate acete articole știre\nAceastă acțiune nu poate fi neterminata';
$lang['error_templatenamexists'] = 'Un şablon cu acest nume deja există';
$lang['error_noarticlesselected'] = 'Nici-un articol nu a fost Selectat';
$lang['reassign_category'] = 'Schimbă Categoria &Icirc;n';
$lang['select'] = 'Selectează';
$lang['approve'] = 'Setează Starea &icirc;n &quot;Publicat&quot;';
$lang['revert'] = 'Setează Starea &icirc;n &quot;Salvate&quot;';
$lang['hide_summary_field'] = 'Ascunde sumarul c&acirc;mpului c&acirc;nd adaugi sau editezi articole';
$lang['textbox'] = 'Introdu Text';
$lang['checkbox'] = 'Verifică căsuţa';
$lang['textarea'] = 'Zonă Text';
$lang['file'] = 'Fişier';
$lang['auto_create_thumbnails'] = 'Crează automat fişiere pictogramă pentru fişiere cu aceste extensii';
$lang['allowed_upload_types'] = 'Permite numai fişiere cu aceste extensii să fie &icirc;ncărcate';
$lang['fielddefupdated'] = 'Definiţia C&acirc;mpului Actualizat ';
$lang['editfielddef'] = 'Editează Difiniţie C&acirc;mp';
$lang['up'] = 'Sus';
$lang['down'] = 'Jos';
$lang['fielddefdeleted'] = 'C&acirc;mp Definiţie Şters';
$lang['nameexists'] = 'Un c&acirc;mp cu acest nume există';
$lang['notanumber'] = 'Lungimea Maximă Nu este un Număr';
$lang['fielddef'] = 'C&acirc;mp Definiţie';
$lang['fielddefadded'] = 'C&acirc;mă Definiţie a fost adăugat cu succes';
$lang['public'] = 'Public ';
$lang['type'] = 'Tip';
$lang['info_maxlength'] = 'Lungimea maximă se aplică numai la cămp cu text introdus ';
$lang['maxlength'] = 'Lungimea Maximă';
$lang['addfielddef'] = 'Adaugă Cămp Definiţie';
$lang['customfields'] = 'C&acirc;mp Definiţie';
$lang['deprecated'] = 'nesuportat';
$lang['subject_newnews'] = 'Un nou articol ştire a fost postat';
$lang['email_subject'] = 'Subiectul  emailului &icirc;n ieşire';
$lang['email_template'] = 'Formatul al mesajului email';
$lang['formsubmit_emailaddress'] = 'Adresa Email să primeşti notificări a ştirilor submise';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Categorie Incărcări';
$lang['title_available_templates'] = 'Şabloane Disponibile';
$lang['resettodefault'] = 'Restează la factori standart';
$lang['title_form_template'] = 'Şablon Formă Editor';
$lang['title_detail_template'] = 'Detaliu Şablon Editor';
$lang['title_summary_template'] = 'Sumar Şablon Editor';
$lang['prompt_templatename'] = 'Nume sablon';
$lang['prompt_template'] = 'Sursă Şabon';
$lang['title_form_sysdefault'] = 'Şablon Standart';
$lang['title_summary_sysdefault'] = 'Sumar Şablon Standart';
$lang['title_detail_sysdefault'] = 'Detaliu Şablon Standart';
$lang['info_sysdefault2'] = '<strong>Notă:</strong> acest tab conţine zone text care permite să editezi un set de şabloane care sunt afikate c&acirc;nd creezi un &quot;nou&quot; sumar, detaliu, sau formă şablon. Schimb&acirc;nd conţinutul &icirc;n acest tab şi apăs&acirc;nd &quot;Submit&quot; nu <strong> va afecta nici un afișaj curent</strong>.';
$lang['info_sysdefault'] = '<em>(conţinutul folosit de standart c&acirc;nd un nou şablon este creat)</em>';
$lang['template'] = 'Şablon';
$lang['prompt_name'] = 'Nume';
$lang['prompt_default'] = 'Standart';
$lang['prompt_newtemplate'] = 'Crează un Şablon Nou';
$lang['help_pagelimit'] = 'Număr maxim de articole să afişeze (pe pagină). Dacă acest parametru nu este aprovizionat  toate articolele potrivite vor fi afişate. Dacă este, şi sunt mai multe articole disponibile decat cele specificate &icirc;n acest parametrum textul şi legăturile vor fi aprovizionate să permită sa vezi prin rezultate';
$lang['prompt_page'] = 'Pagina';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'din';
$lang['prompt_pagelimit'] = 'Pagina Limită';
$lang['prompt_sorting'] = 'Ordonează după';
$lang['title_filter'] = 'Filtre';
$lang['published'] = 'Publicat';
$lang['draft'] = 'Salvat';
$lang['expired'] = 'Expirat';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Restaurare setari implicite';
$lang['restoretodefaultsmsg'] = 'Această operaţie va restaora conținuturile şablonului la sistemul lor standart. Eşti sigur ca vrei să &icirc;naintezi? ';
$lang['addarticle'] = 'Adaugă Articol';
$lang['articleadded'] = 'Articol a fost adaugat cu succes';
$lang['articleupdated'] = 'Articol actualizat cu succes';
$lang['articledeleted'] = 'Articol şters cu succes';
$lang['addcategory'] = 'Adauga Categorie';
$lang['categoryadded'] = 'Categorie adaugată cu succes';
$lang['categoryupdated'] = 'Categoie actualizată cu succes';
$lang['categorydeleted'] = 'Categorie ştersă cu succes';
$lang['addnewsitem'] = 'Adaugare Articol Ştire';
$lang['allcategories'] = 'Toate Categoriile';
$lang['allentries'] = 'Toate Intrările';
$lang['areyousure'] = 'Eşti sigur că vrei să ştergi?';
$lang['articles'] = 'Articole';
$lang['cancel'] = 'Anuleaza';
$lang['category'] = 'Categorie';
$lang['categories'] = 'Categorii';
$lang['default_category'] = 'Categorie Standart';
$lang['content'] = 'Continut';
$lang['dateformat'] = '%s nu este format valid yyyy-mm-dd hh:mm:ss';
$lang['delete'] = 'Stergere';
$lang['description'] = 'Adaugare, editare si stergere iintrari noutati';
$lang['formtemplate'] = 'Template-uri formulare';
$lang['detailtemplate'] = 'Template-uri detalii';
$lang['default_templates'] = 'Template-uri implicite';
$lang['detailtemplateupdated'] = 'Template-ul detalii uploadat a fost salvat cu succes in baza de date.';
$lang['displaytemplate'] = 'Afisare template';
$lang['edit'] = 'Editare';
$lang['enddate'] = 'Data expirarii';
$lang['endrequiresstart'] = 'Daca introduceti o data a expirarii trebuie sa introduceti si o data de start';
$lang['entries'] = '%s Intrari';
$lang['status'] = 'Status ';
$lang['expiry'] = 'Expirare';
$lang['filter'] = 'Filtru';
$lang['more'] = 'Mai mult';
$lang['category_label'] = 'Categorie:';
$lang['author_label'] = 'Postat de:';
$lang['moretext'] = 'Text Mai mult';
$lang['name'] = 'Nume';
$lang['news'] = 'Noutati';
$lang['news_return'] = 'Returnare';
$lang['newcategory'] = 'Categorie noua';
$lang['needpermission'] = 'Aveti nevoie de permissiuni &#039;%s&#039; pentru a afectua aceasta functie.';
$lang['nocategorygiven'] = 'Nu a fost data nici o categorie';
$lang['startdatetoolate'] = 'Data start e prea tarzie (dupa data expirarii?)';
$lang['nocontentgiven'] = 'Nu a fost dat nici un continut';
$lang['noitemsfound'] = '<strong>Niciun</strong> obiect gasit pentru categoria: %s';
$lang['nopostdategiven'] = 'Nu a fost data o dataa postarii';
$lang['note'] = '<em>Nota:</em> Datele trebuie sa aiba formatul &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'Nu a fost dat titlu';
$lang['nonamegiven'] = 'Nu a fost dat nume';
$lang['numbertodisplay'] = 'Numar de afisare (daca e gol se afiseaza toate inregistrarile)';
$lang['print'] = 'Printare';
$lang['postdate'] = 'Data postarii';
$lang['postinstall'] = 'Verificati ca ati setat permisiunile de &quot;Modificare Noutati&quot; pentru utilizatorii care vor administra noutatile.';
$lang['selectcategory'] = 'Selectare categorie';
$lang['showchildcategories'] = 'Afisare categorii copil';
$lang['sortascending'] = 'Sortare ascendent';
$lang['startdate'] = 'Data start';
$lang['startoffset'] = 'Pornire afisare la al n-ulea obiect';
$lang['startrequiresend'] = 'Daca introduceti o data de start trebuie setata si o data de expirare';
$lang['submit'] = 'Trimitere';
$lang['summary'] = 'Sumar';
$lang['summarytemplate'] = 'Template-uri sumar';
$lang['summarytemplateupdated'] = 'Template-ul sumar noutati a fost actualizat cu succes.';
$lang['title'] = 'Titlu';
$lang['options'] = 'Optiuni';
$lang['optionsupdated'] = 'Optiunile au fost actualizate cu succes.';
$lang['useexpiration'] = 'Folosire data expirare';
$lang['eventdesc-NewsArticleAdded'] = 'Trimis cand un articol este adaugat.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Trimis cand un articol este adaugat.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;news_id\&quot; - Id al articolului</li>
<li>\&quot;category_id\&quot; - Id al categoriei acestui articol</li>
<li>\&quot;title\&quot; - Titlul articolului</li>
<li>\&quot;content\&quot; - Continut articol</li>
<li>\&quot;summary\&quot; - Sumar articol</li>
<li>\&quot;status\&quot; - Status articol (&quot;draft&quot; sau &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Data la care articolul ar trebui sa inceapa sa fie afisat</li>
<li>\&quot;end_time\&quot; - Data la care articoul ar trebui sa se opreasca de la afisare</li>
<li>\&quot;useexp\&quot; - Daca data expirarii ar trebui sa fie ignorata sau nu</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Trimis cand un articol este editat.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Trimis cand un articol este editat.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;news_id\&quot; - Id al articolului</li>
<li>\&quot;category_id\&quot; - Id al categoriei acestui articol</li>
<li>\&quot;title\&quot; - Titlul articolului</li>
<li>\&quot;content\&quot; - Continut articol</li>
<li>\&quot;summary\&quot; - Sumar articol</li>
<li>\&quot;status\&quot; - Status articol (&quot;draft&quot; sau &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Data la care articolul ar trebui sa inceapa sa fie afisat</li>
<li>\&quot;end_time\&quot; - Data la care articoul ar trebui sa se opreasca de la afisare</li>
<li>\&quot;useexp\&quot; - Daca data expirarii ar trebui sa fie ignorata sau nu</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Trimis cand un articol este sters.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Trimis cand un articol este sters.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;news_id\&quot; - Id al articolului</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Trimis cand o categorie este adaugata.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Trimis cand o categorie este adaugata.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;category_id\&quot; - Id al categoriei de stiri</li>
<li>\&quot;name\&quot; - Numele categoriei de stiri</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Trimis cand o categorie este editata.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Trimis cand o categorie este editata.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;category_id\&quot; - Id al categoriei de stiri</li>
<li>\&quot;name\&quot; - Numele categoriei de stiri</li>
<li>\&quot;origname\&quot; - Numele original al categoriei de stiri</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Trimis cand o categorie este stearsa.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Trimis cand o categorie este stearsa.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;category_id\&quot; - Id al categoriei de stiri sterse</li>
<li>\&quot;name\&quot; - Numele categoriei de stiri sterse</li>
</ul>
';
$lang['help_articleid'] = 'Acest parametru este aplicabil numai vizualizarii detalii. Permite specificarea a ce articol sa se afiseze in vizualizarea detalii. Daca valoarea speciala -1 este folosita, sistemul va afisa cel mai nou, publicat si non expirat articol.';
$lang['helpnumber'] = 'Numar maxim de articole care se afiseaza (per pagina) -- daca se lasa gol se vor afisa toate articolele. Este un sinonim pentru pagelimit.';
$lang['helpstart'] = 'Pornire afisare la al n-ulea obiect -- daca se lasa gol se va porni de la primul articol.';
$lang['helpcategory'] = 'Folosit in vizualizare sumar pentru a afisa numai articolele pentru categoriile specificate. <b>Folositi * dupa nume pentru a afisa copiii.</b> Multiple categorii pot fi folosite daca sunt separate prin virgula. Daca se lasa gol se vor afisa toate categoriile. Acest parametru functioneaza si pentru actiune submit din frontend, in acest caz un singur nume de categorie este suportat.';
$lang['helpmoretext'] = 'Text care seafiseaza la sfarsitul unui articol daca este mai lung decar sumarul. Implicit este &quot;mai mult...&quot;';
$lang['helpsummarytemplate'] = 'Se foloseste un template din baza de date separat pentru afisare sumar articol. Acest template trebuie sa existe si sa fie vizibil in tabul de template-uri sumar de la administrare noutati, dar nu trebuie sa fie cel implicit. Daca acest parametru nu este specificat, atunci template-ul curent marcat ca implicit va fi folosit.';
$lang['helpformtemplate'] = 'Se foloseste un template din baza de date pentru afisarea formularului de trimitere articol. Acest template trebuie sa existe si sa fie vizibil in tabul template-uri formular de la administrare noutati, dar nu trebuie sa fie cel implicit. Daca acest parametru nu este specificat, atunci template-ul curent marcat ca implicit va fi folosit.';
$lang['helpbrowsecattemplate'] = 'Se foloseste un template din baza de date pentru afisarea navigarii categorie. Acest template trebuie  sa existe si sa fie vizibil in tabul Template-uri navigare categorii de la administrare noutati, dar nu trebuie sa fie cel implicit. Daca acest parametru nu este specificat, atunci template-ul curent marcat implicit va fi folosit.';
$lang['helpdetailtemplate'] = 'Se foloseste un template din baza de date pentru afisarea vizualizarii detaliate articole. Acest template trebuie  sa existe si sa fie vizibil in tabul template-uri detalii de la administrare noutati, dar nu trebuie sa fie cel implicit. Daca acest parametru nu este specificat, atunci template-ul curent marcat implicit va fi folosit.';
$lang['helpsortby'] = 'Campul dupa care se sorteaza.  optiunile sunt: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  Implicit este &quot;news_date&quot;. Daca &quot;random&quot; este specificat, parametrul sortasc este ignorat.';
$lang['helpsortasc'] = 'Se sorteaza articolele de noutati in ordinea ascendenta a datei in loc de cea descendenta.';
$lang['helpdetailpage'] = 'Pagina in care se afiseaza detaliile noutatilor. Poate fi ori un alias de pagina sau un id. Se foloseste pentru ca detaliile sa fie afisate intr-un template diferit de sumar.';
$lang['helpshowarchive'] = 'Afisare numai articole noutati expirate.';
$lang['helpbrowsecat'] = 'Afiseaza o lista navigabila a categoriilor de noutati.';
$lang['helpaction'] = 'Face override la actiunea implicita. Valori posibile sunt:
<ul>
<li>&amp;quot;detail&amp;quot; - pentru afisarea unui anume articol in vizualizarea detaliata.</li>
<li>&amp;quot;default&amp;quot; - pentru afisarea vizualizarii sumar.</li>
<li>&amp;quot;fesubmit&amp;quot; - pentru afisarea formularului frontend pentru a pemite utilizatorilor trimiterea de articole de noutati direct din frontend site.</li>
<li>&amp;quot;browsecat&amp;quot; - pentru a afisa o lista navigabila de categorii noutati.</li>
</ul>';
$lang['help'] = '<h3>Note importante</h3>
<p>This version of News is greater than the one supplied with the 1.1 branch of CMS Made Simple.  If you use this version of News you must use extreme caution when upgrading CMS Made Simple to ensure that nothing in the modules/News directory is overwritten.</p>
	<h3>What does this do?</h3>
	<p>News is a module for displaying news events on your page, similar to a blog style, except with more features!.  When the module is installed, a News admin page is added to administration menu that will allow you to select or add a news category.  Once a news category is created or selected, a list of news items for that category will be displayed.  From here, you can add, edit or delete news items for that category.</p>
        <h4>Numerous display methods</h4>
	<p>The parameters supported by the news module, and support for numerous templates of each time mean that your options for displaying news articles are limitless.</p>
        <h4>Custom Fields</h4>
	<p>The News module allows defining numerous custom fields (including files and images) that will allow you to attach pdf files or numerous images to your articles.</p>
        <h4>Categories</h4>
	<p>News supplies a hierarchical category mechanism for organizing your articles.  A news article can only be in one place in the hierarchy.</p>
        <h4>RSS Feeds</h4>
        <p>News supports generating simple rss feeds from your news articles, so that your visitors can always be up to date with what is happening on your site.</p>
	<h4>Expiry and Status</h4>
	<p>Each news article can have an optional expiry date, after which it will not be shown on your web page.  As well, articles can be marked as <em>draft</em> to remove them permanently from your web page.</p>
	<h3>Security</h3>
	<p>The user must belong to a group with the &#039;Modify News&#039; permission in order to add or edit News entries.</p>
        <p>As well, In order to delete news entries, the user must belong to a group with the &#039;Delete News Articles&#039; permission.</p>
	<p>In order to edit the layout templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>
	<p>In order to edit the global news preferences, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>
	<p>Additionally, to approve news for frontend display the user must belong to a group with the &#039;Approve News&#039; permission.</p>
	<h3>How do I use it?</h3>
	<p>The easiest way to use it is with the {news} wrapper tag (wraps the module in a tag, to simplify the syntax).  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{news number=&#039;5&#039;}</code></p>
<h3>Templates</h3>
	<p>Since version 2.3 News supports multiple database templates, and no longer supports additional file templates.  Users who used the old file template system should follow these steps (for each file template):</p>
<ul>
<li>Copy the file template into the clipboard</li>
<li>Create a new database template <em>(either summary or detailed as required)</em>.  Give the new template the same name (including the .tpl extension) as the old file template, and paste the contents.</li>
<li>Hit Submit</li>
</ul>
<p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
$lang['utma'] = '156861353.1477009656.1272913798.1272913798.1274603745.2';
$lang['utmz'] = '156861353.1274603746.2.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms ms';
$lang['qca'] = 'P0-1739349973-1272913798681';
$lang['utmb'] = '156861353.2.10.1274603745';
$lang['utmc'] = '156861353';
?>